from qq.types import CustomBaseType


class Settings(dict, CustomBaseType):
    pass
